#[non_exhaustive]pub enum PpuSnapshotError {
Truncated(usize),
UnsupportedVersion(u8),
InvalidRegion(u8),
InvalidPresence(u8),
}Expand description
Errors returned by Ppu::restore.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Truncated(usize)
Blob is too short for the version-1 schema.
UnsupportedVersion(u8)
The blob’s version byte is not understood by this build.
InvalidRegion(u8)
Region tag was not one of 0 (NTSC), 1 (PAL), 2 (Dendy).
InvalidPresence(u8)
Optional struct presence byte was something other than 0 or 1.